disabled property
Explicitly disables the button, rendering it in a greyed-out state and blocking interactions.
Implementation
final bool disabled;
Explicitly disables the button, rendering it in a greyed-out state and blocking interactions.
final bool disabled;