isLoading property
Swaps the child for a loading indicator and blocks interactions, but maintains the active button styling.
Implementation
final bool isLoading;
Swaps the child for a loading indicator and blocks interactions, but maintains the active button styling.
final bool isLoading;