IconListTileButton class

A convenience widget that combines an icon with a ListTileButton. Supports a disabled state, shadow color, gradient backgrounds, and multiple sizing constraints.

Inheritance

Constructors

IconListTileButton({Key? key, required IconData icon, required Widget title, Widget? subtitle, Widget? trailing, VoidCallback? onPressed, bool disabled = false, Color? backgroundColor, Gradient? backgroundGradient, Gradient? disabledBackgroundGradient, Color? borderColor, Color? iconColor, Color? shadowColor, double leadingSizeFactor = 1.0, double? elevation, double borderRadius = 10, EdgeInsetsGeometry? margin, EdgeInsetsGeometry? padding = const EdgeInsets.symmetric(horizontal: 8), EdgeInsetsGeometry? bodyPadding, EdgeInsetsGeometry? leadingPadding, EdgeInsetsGeometry? trailingPadding, Alignment contentAlignment = Alignment.centerLeft, double? width, double? height, double? minWidth, double? maxWidth, double minHeight = 60.0, double? maxHeight})
const

Properties

backgroundColor Color?
final
backgroundGradient Gradient?
final
bodyPadding EdgeInsetsGeometry?
final
borderColor Color?
final
borderRadius double
final
contentAlignment Alignment
final
disabled bool
final
disabledBackgroundGradient Gradient?
final
elevation double?
final
hashCode int
The hash code for this object.
no setterinherited
height double?
final
icon IconData
final
iconColor Color?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leadingPadding EdgeInsetsGeometry?
final
leadingSizeFactor double
final
margin EdgeInsetsGeometry?
final
maxHeight double?
final
maxWidth double?
final
minHeight double
final
minWidth double?
final
onPressed VoidCallback?
final
padding EdgeInsetsGeometry?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shadowColor Color?
final
subtitle Widget?
final
title Widget
final
trailing Widget?
final
trailingPadding EdgeInsetsGeometry?
final
width double?
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited