widgets/feedback/risto_notice_card library

Classes

RistoNoticeCard
A standardized, highly customizable card used to display semantic notices.

Enums

RistoNoticeKind
Semantic variations for the RistoNoticeCard.

Typedefs

RistoFooterBuilder = Widget Function(BuildContext context, Color accentColor)
Builder for the footer area of the card, passing down the semantic accent color.