InteractiveMap<T> class

A highly customizable, generic map widget built on top of flutter_map.

Inheritance

Constructors

InteractiveMap({Key? key, required List<T> items, required LatLng positionMapper(T item), required Widget markerBuilder(BuildContext context, T item, int index), MapClusteringConfig? clustering, MapUserLocationConfig? userLocation, MapInteractionConfig<T>? interaction, MapThemeConfig theme = const MapThemeConfig(), InteractiveMapController<T>? controller, MapControlConfig? compassConfig = const MapControlConfig(alignment: Alignment.topRight), MapControlConfig? zoomConfig = const MapControlConfig(alignment: Alignment.bottomRight, padding: EdgeInsets.only(bottom: 90, right: 16)), LatLng initialCenter = const LatLng(45.4642, 9.1900), double initialZoom = 13.0, double markerWidth = 80.0, double markerHeight = 80.0})
const
InteractiveMap.delivery({Key? key, required List<T> items, required LatLng positionMapper(T item), required Widget markerBuilder(BuildContext context, T item, int index), void onDeliveryTapped(T item, int index)?, InteractiveMapController<T>? controller, LatLng initialCenter = const LatLng(45.4642, 9.1900), Color clusterColor = Colors.orange, double markerWidth = 80.0, double markerHeight = 80.0, double? focusedZoom = 15.0, MapInteractionConfig<T>? interaction, MapThemeConfig? theme, MapUserLocationConfig? userLocation, MapControlConfig? zoomConfig})
Factory tailored for Delivery Tracking.
factory
InteractiveMap.locator({Key? key, required List<T> items, required LatLng positionMapper(T item), required Widget markerBuilder(BuildContext context, T item, int index), void onStoreTapped(T item, int index)?, void onMapTapped(TapPosition, LatLng)?, InteractiveMapController<T>? controller, double markerWidth = 80.0, double markerHeight = 80.0, double? focusedZoom = 15.0, MapInteractionConfig<T>? interaction, MapThemeConfig? theme, MapControlConfig? compassConfig = const MapControlConfig(alignment: Alignment.topRight), MapUserLocationConfig? userLocation = const MapUserLocationConfig(followUser: false, requestPermissionAutomatically: false, showUserLocationButton: false, buttonConfig: MapControlConfig(alignment: Alignment.bottomRight)), MapControlConfig? zoomConfig})
Factory tailored for Store Locators / Exploration.
factory

Properties

clustering MapClusteringConfig?
final
compassConfig MapControlConfig?
final
controller InteractiveMapController<T>?
final
hashCode int
The hash code for this object.
no setterinherited
initialCenter → LatLng
final
initialZoom double
final
interaction MapInteractionConfig<T>?
final
items List<T>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
markerBuilder Widget Function(BuildContext context, T item, int index)
final
markerHeight double
final
markerWidth double
final
positionMapper → LatLng Function(T item)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
theme MapThemeConfig
final
userLocation MapUserLocationConfig?
final
zoomConfig MapControlConfig?
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<InteractiveMap<T>>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited