BubbleGroup class
Constructors
-
BubbleGroup({required List<
BubbleNavItem> items, Color? backgroundColor, BorderRadiusGeometry? borderRadius, EdgeInsetsGeometry padding = const EdgeInsets.all(4.0), EdgeInsetsGeometry margin = const EdgeInsets.symmetric(horizontal: 6.0), List<BoxShadow> ? shadows}) -
const
Properties
- backgroundColor → Color?
-
final
- borderRadius → BorderRadiusGeometry?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
BubbleNavItem> -
final
- margin → EdgeInsetsGeometry
-
final
- padding → EdgeInsetsGeometry
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
shadows
→ List<
BoxShadow> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited