MapControlConfig class
Configuration for map control buttons.
Constructors
- MapControlConfig({AlignmentGeometry alignment = Alignment.topRight, EdgeInsets padding = const EdgeInsets.all(16), Widget? icon, Color backgroundColor = Colors.white, Color iconColor = Colors.black87})
-
const
Properties
- alignment → AlignmentGeometry
-
final
- backgroundColor → Color
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Widget?
-
final
- iconColor → Color
-
final
- padding → EdgeInsets
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited