MapInteractionConfig<T> class
Configuration for map interactivity.
Constructors
- MapInteractionConfig({void onTapItem(T item, int index)?, void onMapTap(TapPosition tapPosition, LatLng point)?, void onMapLongPress(TapPosition tapPosition, LatLng point)?, double? focusedZoom = 15.0, bool enableZoom = true, bool enablePan = true, bool enableRotation = false, bool showCompass = true, bool keepAlive = true})
-
const
Properties
- enablePan → bool
-
final
- enableRotation → bool
-
final
- enableZoom → bool
-
final
- focusedZoom → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- keepAlive → bool
-
final
- onMapLongPress → void Function(TapPosition tapPosition, LatLng point)?
-
final
- onMapTap → void Function(TapPosition tapPosition, LatLng point)?
-
final
- onTapItem → void Function(T item, int index)?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCompass → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited